/*************************************************************
 * Author:    wangjiangyuan (wangjiangyuan@agora.io)
 * Date  :    Oct 21th, 2020
 * Module:    Agora SD-RTN SDK RTC C API demo application.
 *
 *
 * This is a part of the Agora RTC Service SDK.
 * Copyright (C) 2020 Agora IO
 * All rights reserved.
 *
 *************************************************************/

#ifndef __MEDIA_PARSER_PRIV_H__
#define __MEDIA_PARSER_PRIV_H__

#include <stdio.h>
#include <stdint.h>
#include "file_parser.h"

#define LOGS(fmt, ...) fprintf(stdout, "" fmt "\n", ##__VA_ARGS__)
#define LOGD(fmt, ...) fprintf(stdout, "[DBG] " fmt "\n", ##__VA_ARGS__)
#define LOGI(fmt, ...) fprintf(stdout, "[INF] " fmt "\n", ##__VA_ARGS__)
#define LOGW(fmt, ...) fprintf(stdout, "[WRN] " fmt "\n", ##__VA_ARGS__)
#define LOGE(fmt, ...) fprintf(stdout, "[ERR] " fmt "\n", ##__VA_ARGS__)

typedef struct media_parser_s media_parser_t;
struct media_parser_s {
	int32_t type;
	int32_t codec;
	void *p_ctx;
	parser_cfg_t parser_cfg;

	int32_t (*open)(media_parser_t *h, const char *path);
	int32_t (*obtain_frame)(media_parser_t *h, frame_t *p_frame);
	int32_t (*reset)(media_parser_t *h);
	int32_t (*close)(media_parser_t *h);
};

/**
 * The definition of the video_codec_e enum.
 */
typedef enum {
	/**
     * 2: h264
     */
	VIDEO_CODEC_H264 = 2,
	/**
     * 6: generic
     */
	VIDEO_CODEC_GENERIC = 6,
} video_codec_e;

/**
 * Audio codec type list.
 */
typedef enum {
	/**
     * 1: OPUS
     */
	AUDIO_CODEC_OPUS = 1,
	/**
     * 5: G722
     */
	AUDIO_CODEC_G722 = 5,
	/**
     * 8: AACLC
     */
	AUDIO_CODEC_AACLC = 8,
	/**
     * 9: HEAAC
     */
	AUDIO_CODEC_HEAAC = 9,
	/**
     * 100: RAW PCM (only supported by RTSA_Lite with audio codec)
     */
	AUDIO_CODEC_PCM = 100,
	/**
     * 253: GENERIC
     */
	AUDIO_CODEC_GENERIC = 253,
} audio_codec_e;

#endif /* __MEDIA_PARSER_PRIV_H__ */